<?php
/************************************************************************
 * MXChange v0.2.1                                    Start: 10/19/2003 *
 * ===============                              Last change: 08/12/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : what-points.php                                  *
 * -------------------------------------------------------------------- *
 * Short description : All your collected points...                     *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Alle Ihrer gesammelten Punkte                    *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * Needs to be in all Files and every File needs "svn propset           *
 * svn:keywords Date Revision" (autoprobset!) at least!!!!!!            *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2008 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	$INC = substr(dirname(__FILE__), 0, strpos(dirname(__FILE__), "/inc") + 4) . "/security.php";
	require($INC);
}

// Sets a status message and code
function WERNIS_STATUS_MESSAGE ($msg, $status) {
	$GLOBALS['wernis_data']['message'] = $msg;
	$GLOBALS['wernis_data']['status'] = $status;
}

// Get the status message
function GET_WERNIS_ERROR_MESSAGE () {
	if (isset($GLOBALS['wernis_data']['message'])) {
		// Use raw message
		return $GLOBALS['wernis_data']['message'];
	} elseif (isset($GLOBALS['wernis_data']['status'])) {
		// Fall-back to status
		return sprintf(WERNIS_ERROR_STATUS, $GLOBALS['wernis_data']['status']);
	} else {
		// Something bad happend
		return WERNIS_UNKNOWN_ERROR;
	}
}

// Get the status code
function GET_WERNIS_ERROR_CODE () {
	if (isset($GLOBALS['wernis_data']['status'])) {
		// Use raw message
		return $GLOBALS['wernis_data']['status'];
	} else {
		// Something bad happend
		return WERNIS_UNKNOWN_ERROR;
	}
}

// Sends out a request to the API and returns it's result
function WERNIS_SEND_REQUEST ($scriptName, $requestData =  array()) {
	// Is the requestData an array?
	if (!is_array($requestData)) {
		// Then abort here!
		return array(
			'status'  => "failed_general",
			'message' => WERNIS_API_REQUEST_DATA_INVALID
		);
	} // END - if

	// Is the API id and MD5 hash there?
	if ((getConfig('wernis_api_id') == "") || (getConfig('wernis_api_md5') == "")) {
		// Abort here...
		return array(
			'status'  => "failed_general",
			'message' => WERNIS_API_REQUEST_DATA_MISSING
		);
	} // END - if

	// Add more request data
	$requestData['api_id']  = getConfig(('wernis_api_id'));
	$requestData['api_key'] = getConfig('wernis_api_md5');

	// Construct the request string
	$requestString = getConfig('wernis_api_url') . $scriptName;

	// Get the raw response from the lower function
	$response = POST_URL($requestString, $requestData);

	// Check the response header if all is fine
	if (strpos($response[0], "200") === false) {
		// Something bad happend... :(
		return array(
			'status'  => "request_error",
			'message' => sprintf(WERNIS_API_REQUEST_ERROR, $response[0])
		);
	} // END - if

	// All (maybe) fine so remove the response header from server
	$response = $response[(count($response) - 1)];

	// Prepare the returning result for higher functions
	if (substr($response, 0, 1) == "&") {
		// Remove the leading & (which can be used in Flash)
		$response = substr($response, 1);
	} // END - if

	// Bring back the response
	$data = explode("=", $response);

	// Default return array (should not stay empty)
	$return = array();

	// We use only the first two entries (which shall be fine)
	if ($data[0] === "error") {
		// The request has failed... :(
		switch ($data[1]) {
			case "404": // Invalid API ID
			case "AUTH": // Authorization has failed
				$return = array(
					'status'  => "auth_failed",
					'message' => WERNIS_API_REQUEST_FAILED_AUTH
				);
				break;

			case "LOCKED": // User account is locked!
			case "PASS": // Bad passphrase entered
			case "USER": // Missing account or invalid password
				$return = array(
					'status'  => "user_failed",
					'message' => WERNIS_API_REQUEST_FAILED_USER
				);
				break;

			case "OWN": // Transfer to own account
				$return = array(
					'status'  => "own_failed",
					'message' => WERNIS_API_REQUEST_FAILED_OWN
				);
				break;

			case "AMOUNT": // Amount is depleted
				$return = array(
					'status'  => "amount_failed",
					'message' => WERNIS_API_REQUEST_FAILED_AMOUNT
				);
				break;

			case "AMOUNT-SEND": // API amount is depleted
				$return = array(
					'status'  => "api_amount_failed",
					'message' => WERNIS_API_REQUEST_FAILED_API_AMOUNT
				);
				break;

			default: // Unknown error (maybe new?)
				DEBUG_LOG(__FUNCTION__, __LINE__, sprintf("Unknown error %s from WDS66 API received.", $data[1]));
				$return = array(
					'status'  => "request_failed",
					'message' => sprintf(WERNIS_API_REQUEST_FAILED, $data[1])
				);
				break;
		}
	} else {
		// All fine here
		$return = array(
			'status'   => "OK",
			'response' => $response
		);
	}

	// Return the result
	return $return;
}

// Tests the function by calling balance.php on the API
function WERNIS_TEST_API () {
	// Result is always failed
	$result = false;

	// Return the result from the lower functions
	$return = WERNIS_SEND_REQUEST("balance.php");

	if ($return['status'] == "OK") {
		// All fine!
		$result = true;
	} else {
		// Status failture text
		WERNIS_STATUS_MESSAGE($return['message'], $return['status']);
	}

	// Return result
	return $result;
}

// Widthdraw this amount
function WERNIS_EXECUTE_WITHDRAW ($wdsId, $userMd5, $amount) {
	// Is the sponsor extension installed?
	if (getConfig('wernis_withdraw_active') != "Y") {
		if (!EXT_IS_ACTIVE("sponsor")) {
			// No, abort here
			return false;
		} elseif (!IS_SPONSOR()) {
			// No sponsor, not allowed to withdraw!
			return false;
		}
	} // END - if

	// Default is failed attempt
	$result = false;

	// Prepare the purpose
	$eval = "\$purpose = \"".COMPILE_CODE(sprintf(WERNIS_API_PURPOSE_WITHDRAW, getUserId()))."\";";
	eval($eval);

	// Prepare the request data
	$requestData = array(
		'sub_request'	=> "receive",
		't_uid'			=> bigintval($wdsId),
		't_md5'			=> $userMd5,
		'r_uid'			=> getConfig('wernis_refid'),
		'amount'		=> bigintval($amount),
		'purpose'		=> encodeString($purpose, false)
	);

	// Return the result from the lower functions
	$return = WERNIS_SEND_REQUEST("book.php", $requestData);

	if ($return['status'] == "OK") {
		// All fine!
		$result = true;

		// Log the transfer
		WERNIS_LOG_TRANSFER($wdsId, $amount, 'IN');
	} else {
		// Status failture text
		WERNIS_STATUS_MESSAGE($return['message'], $return['status']);

		// Log the transfer
		WERNIS_LOG_TRANSFER($wdsId, $amount, 'FAILED', $return['message'], $return['status']);
	}

	// Return result
	return $result;
}


// Payout this amount
function WERNIS_EXECUTE_PAYOUT ($wdsId, $amount) {
	// Default is failed attempt
	$result = false;

	// Prepare the purpose
	$eval = "\$purpose = \"".COMPILE_CODE(sprintf(getMessage('WERNIS_API_PURPOSE_PAYOUT'), getUserId()))."\";";
	eval($eval);

	// Prepare the request data
	$requestData = array(
		'sub_request'	=> "send",
		't_uid'			=> getConfig('wernis_refid'),
		't_md5'			=> getConfig('wernis_pass_md5'),
		'r_uid'			=> bigintval($wdsId),
		'amount'		=> bigintval($amount),
		'purpose'		=> encodeString($purpose, false)
	);

	// Return the result from the lower functions
	$return = WERNIS_SEND_REQUEST("book.php", $requestData);

	if ($return['status'] == "OK") {
		// All fine!
		$result = true;

		// Log the transfer
		WERNIS_LOG_TRANSFER($wdsId, $amount, 'OUT');
	} else {
		// Status failture text
		WERNIS_STATUS_MESSAGE($return['message'], $return['status']);

		// Log the transfer
		WERNIS_LOG_TRANSFER($wdsId, $amount, 'FAILED', $return['message'], $return['status']);
	}

	// Return result
	return $result;
}

// Translate the status IN/OUT
function WERNIS_TRANSFER_STATUS ($status) {
	// Default status
	$return = sprintf(WERNIS_STATUS_UNKNWOWN, $status);
	switch ($status) {
		case "IN": // Withdraw
			$return = WERNIS_STATUS_WITHDRAW;
			break;

		case "OUT": // Payout
			$return = WERNIS_STATUS_PAYOUT;
			break;

		case "FAILED": // Payout
			$return = WERNIS_STATUS_FAILED;
			break;
	}

	// Return the status
	return $return;
}

// Log the transfer
function WERNIS_LOG_TRANSFER ($wdsId, $amount, $type = 'FAILED', $message = "", $status = "") {
	// Register this wernis movement
	SQL_QUERY_ESC("INSERT INTO `{!_MYSQL_PREFIX!}_user_wernis` (`userid`, `wernis_account`, `wernis_amount`, `wernis_timestamp`, `wernis_type`, `wernis_api_message`, `wernis_api_status`) VALUES (%d, %d, %d, UNIX_TIMESTAMP(), '%s', '%s', '%s')",
		array(getUserId(), bigintval($wdsId), bigintval($amount), $type, $message, $status), __FUNCTION__, __LINE__);
}

// Take fees and factor
function WERNIS_TAKE_FEE ($points, $mode) {
	// Payout or withdraw are allowed modes!
	//* DEBUG: */ echo "mode={$mode},points={$points}<br />\n";
	if (!in_array($mode, array('payout', 'withdraw'))) {
		// Log error and abort
		DEBUG_LOG(__FUNCTION__, __LINE__, "uid={getUserId()},mode={$mode},points={$points}");
		return false;
	} // END - if

	// Is there a percentage or fixed fee?
	if (getConfig('wernis_'.$mode.'_fee_percent') > 0) {
		// Percentage fee
		$points -= $points * getConfig('wernis_'.$mode.'_fee_percent') / 100;
	} elseif (getConfig('wernis_'.$mode.'_fee_fix') > 0) {
		// Fixed fee
		$points -= getConfig('wernis_'.$mode.'_fee_fix');
	}

	// Divide/multiply the factor
	if ($mode == "payout") {
		// Divide for payout
		$points = $points / getConfig('wernis_payout_factor');
	} else {
		// Multiply for withdraw
		$points = $points * getConfig('wernis_withdraw_factor');
	}

	// Return value
	//* DEBUG: */ echo "mode={$mode},points={$points}<br />\n";
	return $points;
}

// Add withdraw fees and factor
function WERNIS_ADD_WITHDRAW_FEE ($points) {
	// Is there a percentage or fixed fee?
	if (getConfig('wernis_withdraw_fee_percent') > 0) {
		// Percentage fee
		$points += $points * getConfig('wernis_withdraw_fee_percent') / 100;
	} elseif (getConfig('wernis_withdraw_fee_fix') > 0) {
		// Fixed fee
		$points += getConfig('wernis_withdraw_fee_fix');
	}

	// Return value
	return $points;
}

// Add all fees to the array
function WERNIS_ADD_FEES_TO_ARRAY (&$array) {
	// Is the array an array? ;-)
	if (!is_array($array)) {
		// Log error and return
		DEBUG_LOG(__FUNCTION__, __LINE__, " Type ".gettype($array)." != array.");
		return;
	} // END - if

	// Add both factors
	$array['payout_factor']        = TRANSLATE_COMMA(getConfig('wernis_payout_factor'));
	$array['withdraw_factor']      = TRANSLATE_COMMA(getConfig('wernis_withdraw_factor'));

	// Add all fees
	$array['payout_fee_percent']   = TRANSLATE_COMMA(getConfig('wernis_payout_fee_percent'));
	$array['withdraw_fee_percent'] = TRANSLATE_COMMA(getConfig('wernis_withdraw_fee_percent'));
	$array['payout_fee_fix']       = TRANSLATE_COMMA(getConfig('wernis_payout_fee_fix'));
	$array['withdraw_fee_fix']     = TRANSLATE_COMMA(getConfig('wernis_withdraw_fee_fix'));
}

//
?>
